@@ -3,6 +3,25 @@ constants
 """
 #!/usr/bin/python
 
+import os
+from pathlib import Path
+
+# User
+USER_WAHOO_MC = os.path.join(str(Path.home()), 'wahooMapsCreatorData')
+USER_DL_DIR = os.path.join(USER_WAHOO_MC, '_download')
+USER_MAPS_DIR = os.path.join(USER_DL_DIR, 'maps')
+LAND_POLYGONS_PATH = os.path.join(
+    USER_DL_DIR, 'land-polygons-split-4326', 'land_polygons.shp')
+GEOFABRIK_PATH = os.path.join(USER_DL_DIR, 'geofabrik.json')
+USER_OUTPUT_DIR = os.path.join(USER_WAHOO_MC, '_tiles')
+
+# Python Package - wahooMapsCreator directory
+WAHOO_MC_DIR = os.path.dirname(__file__)
+RESOURCES_DIR = os.path.join(WAHOO_MC_DIR, 'resources')
+TOOLING_WIN_DIR = os.path.join(WAHOO_MC_DIR, 'tooling_win')
+ROOT_DIR = os.path.abspath(os.path.join(os.path.dirname(__file__), os.pardir))
+VERSION = '3.0.0'
+
 Translate_Country = {
     'alaska':                           'united_states_of_america',
     'anguilla':                         'central-america',
@@ -57,7 +76,20 @@ Translate_Country = {
     'western_sahara':                   'morocco',
     'qatar':                            'gcc-states',
     'åland':                            'finland',
-    'new_mexico':                       'new-mexico'
+    'new_mexico':                       'new-mexico',
+    'american_samoa':                   'samoa',
+    'commonwealth_of_the_northern_mariana_islands':                   'american-oceania',
+    'northern_mariana_islands':         'american-oceania',
+    'new_york':                         'new-york',
+    'new_hampshire':                    'new-hampshire',
+    'new_jersey':                       'new-jersey',
+    'rhode_island':                     'rhode-island',
+    'district_of_columbia':             'district-of-columbia',
+    'north_carolina':                   'north-carolina',
+    'south_carolina':                   'south-carolina',
+    'north_dakota':                     'north-dakota',
+    'south_dakota':                     'south-dakota',
+    'west_virginia':                    'west-virginia'
 }
 
 continents = ['europe', 'unitedstates', 'north-america', 'south-america', 'asia', 'oceania',
@@ -148,7 +180,7 @@ asia_geofabrik = ['afghanistan', 'armenia', 'azerbaijan', 'bangladesh', 'bhutan'
                   'pakistan', 'philippines', 'russian federation', 'south-korea', 'sri-lanka', 'syria',
                   'taiwan', 'tajikistan', 'thailand', 'turkmenistan', 'uzbekistan', 'vietnam', 'yemen']
 
-australiaoceania_geofabrik = ['american oceania', 'australia', 'cook islands', 'fiji',
+australiaoceania_geofabrik = ['american-oceania', 'australia', 'cook islands', 'fiji',
                               'île de clipperton', 'kiribati', 'marshall islands', 'micronesia', 'nauru',
                               'new caledonia', 'new zealand', 'niue', 'palau', 'papua new guinea',
                               'pitcairn islands', 'polynesie-francaise', 'samoa', 'solomon islands', 'tokelau',
@@ -220,12 +252,12 @@ TAGS_TO_KEEP_UNIVERSAL = {
     'bridge': '',
     'foot': ['ft_yes', 'foot_designated'],
     'amenity': ['fuel', 'cafe', 'drinking_water'],
-    'shop': 'bakery',
+    'shop': ['bakery', 'bicycle'],
     'highway': ['abandoned', 'bus_guideway', 'disused', 'bridleway', 'byway', 'construction', 'cycleway', 'footway', 'living_street', 'motorway', 'motorway_link', 'path', 'pedestrian', 'primary', 'primary_link', 'residential', 'road', 'secondary', 'secondary_link', 'service', 'steps', 'tertiary', 'tertiary_link', 'track', 'trunk', 'trunk_link', 'unclassified'],
     'natural': ['coastline', 'nosea', 'sea', 'beach', 'land', 'scrub', 'water', 'wetland', 'wood'],
-    'landuse': 'forest',
+    'landuse': ['forest', 'commercial', 'industrial', 'residential', 'retail'],
     'leisure': ['park', 'nature_reserve'],
-    'railway': ['abandoned', 'bus_guideway', 'disused', 'funicular', 'light_rail', 'miniature', 'narrow_gauge', 'preserved', 'rail', 'subway', 'tram'],
+    'railway': ['rail', 'tram', 'station', 'stop'],
     'surface': '',
     'tracktype': '',
     'tunnel': '',
