@@ -8,9 +8,12 @@ import logging
 
 # import custom python packages
 from wahoomc.input import process_call_of_the_tool
-from wahoomc.file_directory_functions import initialize_work_directories
-from wahoomc.file_directory_functions import move_old_content_into_new_dirs
+from wahoomc.setup_functions import initialize_work_directories, \
+    check_installation_of_required_programs, write_config_file, \
+    adjustments_due_to_breaking_changes
+
 from wahoomc.osm_maps_functions import OsmMaps
+from wahoomc.osm_maps_functions import OsmData
 
 # logging used in the terminal output:
 # # means top-level command
@@ -23,7 +26,10 @@ def run():
     main program run
     """
     # create logger
-    logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)
+    logging.basicConfig(format='%(levelname)s:%(message)s',
+                        level=logging.INFO)
+
+    check_installation_of_required_programs()
 
     # handle GUI and CLI processing via one function and different cli-calls
     o_input_data = process_call_of_the_tool()
@@ -31,16 +37,17 @@ def run():
     # Is there something to do?
     o_input_data.is_required_input_given_or_exit(issue_message=True)
 
+    adjustments_due_to_breaking_changes()
     initialize_work_directories()
-    move_old_content_into_new_dirs()
 
-    o_osm_maps = OsmMaps(o_input_data)
+    o_osm_data = OsmData()
+    # Check for not existing or expired files. Mark for download, if dl is needed
+    o_downloader = o_osm_data.process_input_of_the_tool(o_input_data)
 
-    # Read json file
-    # Check for expired land polygons file and download, if too old
-    # Check for expired .osm.pbf files and download, if too old
-    o_osm_maps.process_input(o_input_data.process_border_countries)
-    o_osm_maps.check_and_download_files()
+    # Download files marked for download
+    o_downloader.download_files_if_needed()
+
+    o_osm_maps = OsmMaps(o_osm_data)
 
     if o_input_data.only_merge is False:
         # Filter tags from country osm.pbf files'
@@ -64,10 +71,11 @@ def run():
                                 o_input_data.tag_wahoo_xml)
 
     # Zip .map.lzma files
-    o_osm_maps.make_and_zip_files(
-        o_input_data.keep_map_folders, '.map.lzma', o_input_data.zip_folder)
+    o_osm_maps.make_and_zip_files('.map.lzma', o_input_data.zip_folder)
 
     # Make Cruiser map files zip file
     if o_input_data.save_cruiser is True:
-        o_osm_maps.make_and_zip_files(
-            o_input_data.keep_map_folders, '.map', o_input_data.zip_folder)
+        o_osm_maps.make_and_zip_files('.map', o_input_data.zip_folder)
+
+    # run was successful --> write config file
+    write_config_file()
